Description Usage Arguments Value Examples
Eliminating the Unmeasured Confounders and Estimating Causal Effect for Continuous Outcome.
1 2 3 4 5 6 7 8 |
formula |
an object of class 'formula' : a symbolic description of the model to be fitted |
data |
an optional data frame containing the variables in the model. |
sdmethod |
Choosing a method for estimating variance |
x1_name |
the name of pre-outcome exposure |
x3_name |
the name of post-outcome exposure |
boots_no |
the number of bootstrap |
formula the model
bootstrap the casual effect coefficients
when the variance is calculated by bootstrap
normal the casual effect coefficients
when the variance is calculated in theory
quant the confidence interval
calculated by bootstrap
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.